Hello World example agent that only returns Message events

## Getting started

1. Start the server
    ```bash
    uv run .
    ```

4. Run the test client
    ```bash
    uv run test_client.py
    ```